#reading in the coded data with the sustainability criteria of SWFs
data_sustainability_criteria <- read.csv("Appendix_B2_encoded_individual_sustainability_criteria.csv", sep = ";")

#in the following, the independent variables are read in
#reading in the data with the AUM and the IFSWF membership
data_AUM_IFSWF <- read.csv("Appendix_B3_AUM_and_IFSWF_membership_status.csv", sep = ";")
data_AUM_IFSWF$..Country <- NULL
data_AUM_IFSWF$Sovereign_Wealth_Fund <- NULL

#reading in the data with the V_Dem indicators
data_VDEM_indicators <- read.csv("Appendix_B4_VDEM_selection.csv", sep = ",")
data_VDEM_indicators$X <- NULL
data_VDEM_indicators$country_name <- NULL

#reading in the IEA data
data_IEA <- read.csv("Appendix_B5_crude_oil_exports.csv", sep = ";")
data_IEA$Sovereign_Wealth_Fund <- NULL
data_IEA$..Country <- NULL

#reading in the demographic data
demography_2016 <- read.csv("Appendix_B6_demography.csv", sep = ",")
demography_2016$X <- NULL
demography_2016$country_name <- NULL
demography_2016$total <- NULL

#reading in the origin of funding
data_origin_of_funding <- read.csv("Appendix_B7_origin_of_funding.csv", sep = ";")
data_origin_of_funding$Sovereign_Wealth_Fund <- NULL
data_origin_of_funding$Funding_Boubakri <- NULL

#Building the score values as the dependent variables using additive concepts
data_sustainability_criteria$environmental_score <- data_sustainability_criteria$X1_1_Promotion_of_renewable_energy + data_sustainability_criteria$X1_2_Reduction_of_fossil_energy + data_sustainability_criteria$X1_3_Reduction_of_air_water_and_soil_pollution + data_sustainability_criteria$X1_4_Promotion_of_sustainable_agriculture
data_sustainability_criteria$social_score <- data_sustainability_criteria$X2_1_Protection_of_human_rights + data_sustainability_criteria$X2_2_Building_human_capital_and_or_education + data_sustainability_criteria$X2_3_Promotion_of_poverty_reduction + data_sustainability_criteria$X2_4_Promotion_of_sustainable_health_services
data_sustainability_criteria$governance_score <- data_sustainability_criteria$X3_1_Board_composition_and_leadership + data_sustainability_criteria$X3_2_Risk_management_financial + data_sustainability_criteria$X3_3_Risk_management_climate + data_sustainability_criteria$X3_4_Business_ethics + data_sustainability_criteria$X3_5_Transparency_of_investment + data_sustainability_criteria$X3_6_Responsible_ownership
data_sustainability_criteria$economic_score <- data_sustainability_criteria$X4_1_Promotion_of_sustainable_innovations + data_sustainability_criteria$X4_2_Promotion_of_sustainable_infrastructure + data_sustainability_criteria$X4_3_Prohibition_to_support_unsustainable_business_practices + data_sustainability_criteria$X4_4_Support_local_economy + data_sustainability_criteria$X4_5_Investment_to_promote_developing_countries
data_sustainability_criteria$overall_score <- data_sustainability_criteria$environmental_score + data_sustainability_criteria$social_score + data_sustainability_criteria$governance_score + data_sustainability_criteria$economic_score


#Building the dataset for regresstion
data_regression <- subset(data_sustainability_criteria, select = c(Sovereign.Wealth.Fund, no_pension_fund, environmental_score, social_score, governance_score, economic_score, overall_score))
data_regression <- cbind(data_regression, data_VDEM_indicators, data_AUM_IFSWF, demography_2016, data_IEA, data_origin_of_funding)

#Conducting the main regression models
lm_environmental_score <- lm(environmental_score ~ no_pension_fund + AUM_2016 + other_than_natural_resource + e_migdppc +  crude_oil_export + pop_ages_0_14 + v2x_polyarchy + e_wbgi_gee + IFSWF_membership, data_regression)
lm_social_score <- lm(social_score ~ no_pension_fund + AUM_2016 + other_than_natural_resource + e_migdppc +  crude_oil_export + pop_ages_0_14 + v2x_polyarchy + e_wbgi_gee + IFSWF_membership, data_regression)
lm_governance_score <- lm(governance_score ~ no_pension_fund + AUM_2016 + other_than_natural_resource + e_migdppc +  crude_oil_export + pop_ages_0_14 + v2x_polyarchy + e_wbgi_gee + IFSWF_membership, data_regression)
lm_economic_score <- lm(economic_score ~ no_pension_fund + AUM_2016 + other_than_natural_resource + e_migdppc +  crude_oil_export + pop_ages_0_14 + v2x_polyarchy + e_wbgi_gee + IFSWF_membership, data_regression)

lm_overall_score <- lm(overall_score ~ no_pension_fund + AUM_2016 + other_than_natural_resource + e_migdppc +  crude_oil_export + pop_ages_0_14 + v2x_polyarchy + e_wbgi_gee + IFSWF_membership, data_regression)
#Conducting robustness check models including the percentage of people older than 65 instead of the percentage of people under 14
lm_environmental_score_over_65 <- lm(environmental_score ~ no_pension_fund + AUM_2016 + other_than_natural_resource + e_migdppc +  crude_oil_export + pop_ages_over_65 + v2x_polyarchy + e_wbgi_gee + IFSWF_membership, data_regression)
lm_social_score_over_65 <- lm(social_score ~ no_pension_fund + AUM_2016 + other_than_natural_resource + e_migdppc +  crude_oil_export + pop_ages_over_65 + v2x_polyarchy + e_wbgi_gee + IFSWF_membership, data_regression)
lm_governance_score_over_65 <- lm(governance_score ~ no_pension_fund + AUM_2016 + other_than_natural_resource + e_migdppc +  crude_oil_export + pop_ages_over_65 + v2x_polyarchy + e_wbgi_gee + IFSWF_membership, data_regression)
lm_economic_score_over_65 <- lm(economic_score ~ no_pension_fund + AUM_2016 + other_than_natural_resource + e_migdppc +  crude_oil_export + pop_ages_over_65 + v2x_polyarchy + e_wbgi_gee + IFSWF_membership, data_regression)

lm_overall_score_over_65 <- lm(overall_score ~ no_pension_fund + AUM_2016 + other_than_natural_resource + e_migdppc +  crude_oil_export + pop_ages_over_65 + v2x_polyarchy + e_wbgi_gee + IFSWF_membership, data_regression)





#the coefficients for the AUM, GDP/capita and the crude oil exports are small
#rescaling can be applied in order obtain more practical scales
#the rescaling has to be considered in the interpretation of the model
data_regression$AUM_2016 <- data_regression$AUM_2016/1000
data_regression$e_migdppc <- data_regression$e_migdppc/1000
data_regression$crude_oil_export <- data_regression$crude_oil_export/1000
#following this rescaling, the models can be compiled again

#Use Paket Stargazer for output
#the documentation: https://cran.r-project.org/web/packages/stargazer/vignettes/stargazer.pdf
#the display of the significance stars has to be adapted
#https://stackoverflow.com/questions/51744856/display-p-values-under-0-1-in-r-stargazer
#https://www.rdocumentation.org/packages/stargazer/versions/5.2.2/topics/stargazer
library(stargazer)
#exporting the main models
stargazer(lm_environmental_score, lm_social_score, lm_governance_score, lm_economic_score, lm_overall_score, star.char = c("*", "**", "***"), star.cutoffs = c(.05, .01, .001), type="html", out="regression_results_rescaled_main_models.doc")
#exporting the robustness check models
stargazer(lm_environmental_score_over_65, lm_social_score_over_65, lm_governance_score_over_65, lm_economic_score_over_65, lm_overall_score_over_65, star.char = c("*", "**", "***"), star.cutoffs = c(.05, .01, .001), type="html", out="regression_results_rescaled_robustness_check_models.doc")


#Diagnostics are applied to the Models
#Valiance Inflation Factor (VIF) Calculation
#loading the library olsrr
library(olsrr)
#the VIF is the same for all models and is therefore only calculated for the overall score
ols_vif_tol(lm_overall_score)
#Heteroscedasticity Test
library(lmtest)
bptest(lm_environmental_score)
bptest(lm_social_score)
bptest(lm_governance_score)
bptest(lm_economic_score)
bptest(lm_overall_score)
#Testing for the Normal Distribution of Residuals
ols_test_normality(lm_environmental_score)
ols_test_normality(lm_social_score)
ols_test_normality(lm_governance_score)
ols_test_normality(lm_economic_score)
ols_test_normality(lm_overall_score)


#Making the Comparison to the Megginson Indexes
#reading in the Megginson Indexes
comparison_megginson <- read.csv("Appendix_B8_comparison_megginson_GSR.csv", sep = ";")
comparison_megginson <- subset(comparison_megginson, select = c(G, S, R, GSR))
#extracting the required data from our dataset
data_regression_extract <- subset(data_regression, select = c(Sovereign.Wealth.Fund, v2x_polyarchy, e_wbgi_gee, overall_score))
#combining the Megginson Indexes and the extract of our dataset into one dataset
correlation_calculation_megginson <- cbind(data_regression_extract, comparison_megginson)
#Missing cases can either be filled with zeros or omitted
#However, omitting missing cases appears more appropriate
#Now, the missing cases are omitted
correlation_calculation_megginson_NA_omitted <- correlation_calculation_megginson
correlation_calculation_megginson_NA_omitted <- correlation_calculation_megginson_NA_omitted[complete.cases(correlation_calculation_megginson_NA_omitted),]
#now, the correlation calculatons are applied
#State Capacity and Megginsons S
cor(correlation_calculation_megginson_NA_omitted$e_wbgi_gee, correlation_calculation_megginson_NA_omitted$S)
# 0.4502006
#Democracy and Megginsons S
cor(correlation_calculation_megginson_NA_omitted$v2x_polyarchy, correlation_calculation_megginson_NA_omitted$S)
# 0.3482527
#State Capacity and Meginsons GSR
cor(correlation_calculation_megginson_NA_omitted$e_wbgi_gee, correlation_calculation_megginson_NA_omitted$GSR)
# 0.5528978
#Democratization and Megginsons GSR
cor(correlation_calculation_megginson_NA_omitted$v2x_polyarchy, correlation_calculation_megginson_NA_omitted$GSR)
# 0.6431567
#Our Overall Score and Megginsons S
cor(correlation_calculation_megginson_NA_omitted$overall_score, correlation_calculation_megginson_NA_omitted$S)
# 0.8149598
#Our Overall Score and Megginsons GSR
cor(correlation_calculation_megginson_NA_omitted$overall_score, correlation_calculation_megginson_NA_omitted$GSR)
# 0.6718004
